@@ -93,6 +93,7 @@ void sstp_usage_die(const char *prog, int code,
     printf("  --user                   Username\n");
     printf("  --save-server-route      Add route to VPN server\n");
     printf("  --uuid                   The connection id\n");
+    printf("  --tls-ext                Enable TLS hostname extension\n");
     printf("  --version                Display the version information\n\n");
 
     /* Additional log usage */
@@ -205,11 +206,15 @@ static void sstp_parse_option(sstp_option_st *ctx, int argc, char **argv, int in
         break;
 
     case 14:
-	if (getuid() != 0)
+        if (getuid() != 0)
            sstp_die("Can only save server route when run as root", -1);
         ctx->enable |= SSTP_OPT_SAVEROUTE;
         break;
 
+    case 15:
+        ctx->enable |= SSTP_OPT_TLSEXT;
+        break;
+
     default:
         sstp_usage_die(argv[0], -1, "Unrecognized command line option");
         break;
@@ -279,6 +284,7 @@ int sstp_parse_argv(sstp_option_st *ctx, int argc, char **argv)
         { "user",           required_argument, NULL,  0  },
         { "uuid",           required_argument, NULL,  0  },
         { "save-server-route", no_argument,    NULL,  0  },
+        { "tls-ext",        no_argument,       NULL,  0  },
         { "version",        no_argument,       NULL, 'v' },
         { 0, 0, 0, 0 }
     };
